@@ -45,8 +45,7 @@ class R3sponse(object):
 		response["message"] = message
 		for key, value in variables.items():
 			response[key] = value
-		if log_level != None and self.log_level >= log_level: print(response["message"])
-		if save: self.__log_to_file__(response["message"])
+		r3sponse.log(message=response["message"], log_level=log_level, save=save)
 		if django: response = JsonResponse(response)
 		return response
 	def error_response(self,
@@ -61,8 +60,7 @@ class R3sponse(object):
 	):
 		response = self.default_response()
 		response["error"] = error
-		if log_level != None and self.log_level >= log_level: print(response["error"])
-		if save: self.__log_to_file__(response["error"])
+		r3sponse.log(error=response["error"], log_level=log_level, save=save)
 		if django: response = JsonResponse(response)
 		return response
 		#
@@ -145,7 +143,14 @@ class R3sponse(object):
 			msg = f"Error: {error}"
 		else: 
 			msg = message
-		if log_level >= self.log_level:
+		try:
+			comparison = log_level != None and log_level >= self.log_level
+		except TypeError as e:
+			if "not supported between instances of 'dict' and 'int'" in f"{e}":
+				raise TypeError(f"You most likely returned a r3sponse.error_response when you meant a r3sponse.success_response, error: {e}")
+			else:
+				raise TypeError(e)
+		if comparison:
 			print(f"{Formats.Date().seconds_timestamp} - {color.fill(msg)}")
 		if save: 
 			self.__log_to_file__(msg)
